@@ -6,6 +6,7 @@ use wiremock::matchers::{method, path, query_param};
 use wiremock::{Mock, MockServer, ResponseTemplate};
 
 use super::utils::credentials;
+use super::utils::no_credentials;
 
 #[rstest(body, response_str, expected,
     case(
@@ -86,7 +87,11 @@ async fn test_create(
     )
 )]
 #[actix_rt::test]
-async fn test_get(credentials: types::Credentials, response_str: &str, expected: types::Changeset) {
+async fn test_get(
+    no_credentials: types::Credentials,
+    response_str: &str,
+    expected: types::Changeset,
+) {
     /*
     GIVEN an OSM client
     WHEN calling the get() function with a changeset ID
@@ -102,7 +107,7 @@ async fn test_get(credentials: types::Credentials, response_str: &str, expected:
         .mount(&mock_server)
         .await;
 
-    let client = Openstreetmap::new(mock_server.uri(), credentials);
+    let client = Openstreetmap::new(mock_server.uri(), no_credentials);
 
     // WHEN
     let actual = client.changeset().get(10).await.unwrap();
@@ -153,7 +158,7 @@ async fn test_get(credentials: types::Credentials, response_str: &str, expected:
 )]
 #[actix_rt::test]
 async fn test_get_with_discussion(
-    credentials: types::Credentials,
+    no_credentials: types::Credentials,
     response_str: &str,
     expected: types::Changeset,
 ) {
@@ -174,7 +179,7 @@ async fn test_get_with_discussion(
         .mount(&mock_server)
         .await;
 
-    let client = Openstreetmap::new(mock_server.uri(), credentials);
+    let client = Openstreetmap::new(mock_server.uri(), no_credentials);
 
     // WHEN
     let actual = client.changeset().get_with_discussion(10).await.unwrap();
@@ -294,12 +299,46 @@ async fn test_close(credentials: types::Credentials) {
                     id: 1234,
                     changeset: 42,
                     version: 2,
-                    uid: 1,
+                    uid: Some(1),
                     timestamp: "2009-12-09T08:19:00Z".into(),
-                    user: "user".into(),
+                    user: Some("user".into()),
                     visible: true,
-                    lat: 12.1234567,
-                    lon: -8.7654321,
+                    lat: Some(12.1234567),
+                    lon: Some(-8.7654321),
+                    tags: vec![types::Tag {
+                        k: "amenity".into(),
+                        v: "school".into(),
+                    }],
+                }],
+                ways: vec![],
+                relations: vec![],
+            }],
+            creations: vec![],
+            deletions: vec![],
+        }
+    ),
+    case(
+        r#"
+        <osmChange version="0.6" generator="acme osm editor">
+            <modify>
+                <node id="1234" changeset="42" version="2" timestamp="2009-12-09T08:19:00Z" visible="true">
+                    <tag k="amenity" v="school"/>
+                </node>
+            </modify>
+        </osmChange>
+        "#,
+        types::ChangesetChanges {
+            modifications: vec![types::Modification {
+                nodes: vec![types::Node {
+                    id: 1234,
+                    changeset: 42,
+                    version: 2,
+                    uid: None,
+                    timestamp: "2009-12-09T08:19:00Z".into(),
+                    user: None,
+                    visible: true,
+                    lat: None,
+                    lon: None,
                     tags: vec![types::Tag {
                         k: "amenity".into(),
                         v: "school".into(),
@@ -315,7 +354,7 @@ async fn test_close(credentials: types::Credentials) {
 )]
 #[actix_rt::test]
 async fn test_download(
-    credentials: types::Credentials,
+    no_credentials: types::Credentials,
     response_str: &str,
     expected: types::ChangesetChanges,
 ) {
@@ -335,7 +374,7 @@ async fn test_download(
         .mount(&mock_server)
         .await;
 
-    let client = Openstreetmap::new(mock_server.uri(), credentials);
+    let client = Openstreetmap::new(mock_server.uri(), no_credentials);
 
     // WHEN
     let actual = client.changeset().download(10).await.unwrap();
@@ -352,12 +391,12 @@ async fn test_download(
                     id: 1234,
                     changeset: 42,
                     version: 2,
-                    uid: 1,
+                    uid: Some(1),
                     timestamp: "2009-12-09T08:19:00Z".into(),
-                    user: "user".into(),
+                    user: Some("user".into()),
                     visible: true,
-                    lat: 12.1234567,
-                    lon: -8.7654321,
+                    lat:Some( 12.1234567),
+                    lon: Some(-8.7654321),
                     tags: vec![types::Tag {
                         k: "amenity".into(),
                         v: "school".into(),
