@@ -6,3 +6,9 @@ use rstest::fixture;
 pub fn credentials() -> types::Credentials {
     types::Credentials::Basic("user".into(), "password".into())
 }
+
+#[fixture]
+#[inline]
+pub fn no_credentials() -> types::Credentials {
+    types::Credentials::None
+}
